@@ -78,12 +78,19 @@ You may turn off/on adding newlines by passing ``newlines=False`` or
    >>> print h
    <ol><li>item 1</li><li>item 2</li></ol>
 
+Since we can't use ``class`` as a keyword, the library recognises ``klass``
+as a substitute::
+
+   >>> print h.p(content, klass="styled)
+   <p class="styled">content</p>
+
+
 ----
 
 This code is copyright 2009 eKit.com Inc (http://www.ekit.com/)
 See the end of the source file for the license of use.
 '''
-__version__ = '1.1'
+__version__ = '1.2'
 
 import unittest
 import cgi
@@ -134,7 +141,10 @@ class HTML(object):
             # special-case to allow control over newlines
             self.newlines = kw.pop('newlines')
         for k in kw:
-            self.attrs[k] = cgi.escape(kw[k], True)
+            if k == 'klass':
+                self.attrs['class'] = cgi.escape(kw[k], True)
+            else:
+                self.attrs[k] = cgi.escape(kw[k], True)
         return self
     def __enter__(self):
         # we're now adding tags to me!
